@@ -187,11 +187,16 @@ notify_deselect (gpointer data)
 {
   GailCombo *combo;
 
+  GDK_THREADS_ENTER ();
+
   combo = GAIL_COMBO (data);
 
   combo->old_selection = NULL;
   combo->deselect_idle_handler = 0;
   g_signal_emit_by_name (data, "selection_changed");
+
+  GDK_THREADS_LEAVE ();
+
   return FALSE;
 }
 
@@ -200,10 +205,15 @@ notify_select (gpointer data)
 {
   GailCombo *combo;
 
+  GDK_THREADS_ENTER ();
+
   combo = GAIL_COMBO (data);
 
   combo->select_idle_handler = 0;
   g_signal_emit_by_name (data, "selection_changed");
+
+  GDK_THREADS_LEAVE ();
+
   return FALSE;
 }
 
@@ -359,17 +369,17 @@ idle_do_action (gpointer data)
   gboolean do_popup;
   GdkEvent tmp_event;
 
+  GDK_THREADS_ENTER ();
+
   gail_combo = GAIL_COMBO (data);
   gail_combo->action_idle_handler = 0;
   widget = GTK_ACCESSIBLE (gail_combo)->widget;
-  if (widget == NULL)
-    /*
-     * State is defunct
-     */
-    return FALSE;
-
-  if (!GTK_WIDGET_SENSITIVE (widget) || !GTK_WIDGET_VISIBLE (widget))
-    return FALSE;
+  if (widget == NULL /* State is defunct */ ||
+      !GTK_WIDGET_SENSITIVE (widget) || !GTK_WIDGET_VISIBLE (widget))
+    {
+      GDK_THREADS_LEAVE ();
+      return FALSE;
+    }
 
   combo = GTK_COMBO (widget);
 
@@ -401,6 +411,9 @@ idle_do_action (gpointer data)
       gtk_widget_event (action_widget, &tmp_event);
       g_idle_add (_gail_combo_popup_release, combo);
     }
+
+  GDK_THREADS_LEAVE ();
+
   return FALSE;
 }
 
@@ -607,9 +620,14 @@ _gail_combo_popup_release (gpointer data)
   GtkWidget *action_widget;
   GdkEvent tmp_event;
 
+  GDK_THREADS_ENTER ();
+
   combo = GTK_COMBO (data);
   if (combo->current_button == 0)
-    return FALSE;
+    {
+      GDK_THREADS_LEAVE ();
+      return FALSE;
+    }
 
   tmp_event.button.type = GDK_BUTTON_RELEASE; 
   tmp_event.button.button = 1; 
@@ -618,6 +636,8 @@ _gail_combo_popup_release (gpointer data)
 
   gtk_widget_event (action_widget, &tmp_event);
 
+  GDK_THREADS_LEAVE ();
+
   return FALSE;
 }
 
@@ -628,9 +648,14 @@ _gail_combo_button_release (gpointer data)
   GtkWidget *action_widget;
   GdkEvent tmp_event;
 
+  GDK_THREADS_ENTER ();
+
   combo = GTK_COMBO (data);
   if (combo->current_button == 0)
-    return FALSE;
+    {
+      GDK_THREADS_LEAVE ();
+      return FALSE;
+    }
 
   tmp_event.button.type = GDK_BUTTON_RELEASE; 
   tmp_event.button.button = 1; 
@@ -641,6 +666,8 @@ _gail_combo_button_release (gpointer data)
 
   gtk_widget_event (action_widget, &tmp_event);
 
+  GDK_THREADS_LEAVE ();
+
   return FALSE;
 }
 
