@@ -21,6 +21,7 @@
 #include <gtk/gtk.h>
 #include "gailnotebook.h"
 #include "gailnotebookpage.h"
+#include "gail-private-macros.h"
 
 static void         gail_notebook_class_init          (GailNotebookClass *klass);
 static void         gail_notebook_object_init         (GailNotebook      *notebook);
@@ -375,7 +376,7 @@ gail_notebook_ref_selection (AtkSelection *selection,
   /*
    * A note book can have only one selection.
    */
-  g_return_val_if_fail (i == 0, NULL);
+  gail_return_val_if_fail (i == 0, NULL);
   g_return_val_if_fail (GAIL_IS_NOTEBOOK (selection), NULL);
   
   widget = GTK_ACCESSIBLE (selection)->widget;
@@ -385,7 +386,7 @@ gail_notebook_ref_selection (AtkSelection *selection,
   
   notebook = GTK_NOTEBOOK (widget);
   pagenum = gtk_notebook_get_current_page (notebook);
-  g_return_val_if_fail (pagenum != -1, NULL);
+  gail_return_val_if_fail (pagenum != -1, NULL);
   accessible = gail_notebook_ref_child (ATK_OBJECT (selection), pagenum);
 
   return accessible;
@@ -521,7 +522,7 @@ create_notebook_page_accessible (GailNotebook *gail_notebook,
   g_signal_connect (gtk_notebook_get_nth_page (notebook, index), 
                     "parent_set",
                     G_CALLBACK (gail_notebook_child_parent_set),
-                    GINT_TO_POINTER (index));
+                    obj);
 }
 
 static void
@@ -531,9 +532,9 @@ gail_notebook_child_parent_set (GtkWidget *widget,
 {
   GailNotebook *gail_notebook;
 
-  g_return_if_fail (old_parent != NULL);
+  gail_return_if_fail (old_parent != NULL);
   gail_notebook = GAIL_NOTEBOOK (gtk_widget_get_accessible (old_parent));
-  gail_notebook->remove_index = GPOINTER_TO_INT (data);
+  gail_notebook->remove_index = GAIL_NOTEBOOK_PAGE (data)->index;
 }
 
 static gint
@@ -593,6 +594,8 @@ gail_notebook_check_focus_tab (gpointer data)
   GailNotebook *gail_notebook;
   GtkNotebook *gtk_notebook;
 
+  GDK_THREADS_ENTER ();
+
   atk_obj = ATK_OBJECT (data);
   gail_notebook = GAIL_NOTEBOOK (atk_obj);
   widget = GTK_ACCESSIBLE (atk_obj)->widget;
@@ -602,7 +605,10 @@ gail_notebook_check_focus_tab (gpointer data)
   gail_notebook->idle_focus_id = 0;
 
   if (!gtk_notebook->focus_tab)
-    return FALSE;
+    {
+      GDK_THREADS_LEAVE ();
+      return FALSE;
+    }
 
   old_focus_page_num = gail_notebook->focus_tab_page;
   focus_page_num = g_list_index (gtk_notebook->children, gtk_notebook->focus_tab->data);
@@ -615,6 +621,9 @@ gail_notebook_check_focus_tab (gpointer data)
       atk_focus_tracker_notify (obj);
       g_object_unref (obj);
     }
+
+  GDK_THREADS_LEAVE ();
+
   return FALSE;
 }
 
