@@ -21,6 +21,7 @@
 #include <gtk/gtk.h>
 #include "gailwindow.h"
 #include "gailtoplevel.h"
+#include "gail-private-macros.h"
 
 enum {
   ACTIVATE,
@@ -213,13 +214,13 @@ gail_window_new (GtkWidget *widget)
   GObject *object;
   AtkObject *accessible;
 
-  g_return_val_if_fail (widget != NULL, NULL);
+  gail_return_val_if_fail (widget != NULL, NULL);
   /*
    * A GailWindow can be created for a GtkHandleBox or a GtkWindow
    */
   if (!GTK_IS_WINDOW (widget) &&
       !GTK_IS_HANDLE_BOX (widget))
-    g_return_val_if_fail (FALSE, NULL);
+    gail_return_val_if_fail (FALSE, NULL);
 
   object = g_object_new (GAIL_TYPE_WINDOW, NULL);
 
@@ -321,7 +322,7 @@ gail_window_get_name (AtkObject *accessible)
          */
         return NULL;
 
-      g_return_val_if_fail (GTK_IS_WIDGET (widget), NULL);
+      gail_return_val_if_fail (GTK_IS_WIDGET (widget), NULL);
 
       if (GTK_IS_WINDOW (widget))
         {
@@ -334,7 +335,12 @@ gail_window_get_name (AtkObject *accessible)
               GtkWidget *child;
 
               child = gtk_bin_get_child (GTK_BIN (window));
-              g_return_val_if_fail (GTK_IS_LABEL (child), NULL);
+	      /* could be some kind of egg notification bubble thingy? */
+              if (!GTK_IS_LABEL (child)) 
+	      { 
+		  g_message ("ATK_ROLE_TOOLTIP object found, but doesn't look like a tooltip.");
+		  return NULL;
+	      }
               name = gtk_label_get_text (GTK_LABEL (child));
             }
         }
@@ -366,7 +372,7 @@ gail_window_get_index_in_parent (AtkObject *accessible)
      */
     return -1;
 
-  g_return_val_if_fail (GTK_IS_WIDGET (widget), -1);
+  gail_return_val_if_fail (GTK_IS_WIDGET (widget), -1);
 
   index = ATK_OBJECT_CLASS (parent_class)->get_index_in_parent (accessible);
   if (index != -1)
@@ -403,7 +409,7 @@ gail_window_ref_relation_set (AtkObject *obj)
   GtkWidget *current_widget;
   gboolean ret;
 
-  g_return_val_if_fail (GAIL_IS_WIDGET (obj), NULL);
+  gail_return_val_if_fail (GAIL_IS_WIDGET (obj), NULL);
 
   widget = GTK_ACCESSIBLE (obj)->widget;
   if (widget == NULL)
@@ -548,7 +554,7 @@ gail_window_state_event_gtk (GtkWidget           *widget,
 static void
 atk_component_interface_init (AtkComponentIface *iface)
 {
-  g_return_if_fail (iface != NULL);
+  gail_return_if_fail (iface != NULL);
 
   iface->get_extents = gail_window_get_extents;
   iface->get_size = gail_window_get_size;
@@ -573,7 +579,7 @@ gail_window_get_extents (AtkComponent  *component,
      */
     return;
 
-  g_return_if_fail (GTK_IS_WINDOW (widget));
+  gail_return_if_fail (GTK_IS_WINDOW (widget));
 
   if (!GTK_WIDGET_TOPLEVEL (widget))
     {
@@ -618,7 +624,7 @@ gail_window_get_size (AtkComponent *component,
      */
     return;
 
-  g_return_if_fail (GTK_IS_WINDOW (widget));
+  gail_return_if_fail (GTK_IS_WINDOW (widget));
 
   if (!GTK_WIDGET_TOPLEVEL (widget))
     {
@@ -953,7 +959,7 @@ get_screen_info (GdkScreen *screen)
 {
   int screen_n;
 
-  g_return_val_if_fail (GDK_IS_SCREEN (screen), NULL);
+  gail_return_val_if_fail (GDK_IS_SCREEN (screen), NULL);
 
   screen_n = gdk_screen_get_number (screen);
 
@@ -981,12 +987,12 @@ get_window_zorder (GdkWindow *window)
   int             zorder;
   int             w_desktop;
 
-  g_return_val_if_fail (GDK_IS_WINDOW (window), -1);
+  gail_return_val_if_fail (GDK_IS_WINDOW (window), -1);
 
   info = get_screen_info (
 		gdk_drawable_get_screen (GDK_DRAWABLE (window)));
 
-  g_return_val_if_fail (info->stacked_windows != NULL, -1);
+  gail_return_val_if_fail (info->stacked_windows != NULL, -1);
 
   xid = GDK_WINDOW_XID (window);
 
@@ -1030,7 +1036,7 @@ gail_window_get_mdi_zorder (AtkComponent *component)
      */
     return -1;
 
-  g_return_val_if_fail (GTK_IS_WINDOW (widget), -1);
+  gail_return_val_if_fail (GTK_IS_WINDOW (widget), -1);
 
   return get_window_zorder (widget->window);
 }
@@ -1048,7 +1054,7 @@ gail_window_get_mdi_zorder (AtkComponent *component)
      */
     return -1;
 
-  g_return_val_if_fail (GTK_IS_WINDOW (widget), -1);
+  gail_return_val_if_fail (GTK_IS_WINDOW (widget), -1);
 
   return 0;			/* Punt, FIXME */
 }
